==> cdktf-provider-google-13.1.0-sources.jar: com/hashicorp/cdktf/providers/google/cloudbuildv2_connection/Cloudbuildv2ConnectionGitlabConfigReadAuthorizerCredential.java <==
package com.hashicorp.cdktf.providers.google.cloudbuildv2_connection;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-17T04:17:39.221Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.cloudbuildv2Connection.Cloudbuildv2ConnectionGitlabConfigReadAuthorizerCredential")
@software.amazon.jsii.Jsii.Proxy(Cloudbuildv2ConnectionGitlabConfigReadAuthorizerCredential.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface Cloudbuildv2ConnectionGitlabConfigReadAuthorizerCredential extends software.amazon.jsii.JsiiSerializable {

    /**
     * Required. A SecretManager resource containing the user token that authorizes the Cloud Build connection. Format: <code>projects/* /secrets/* /versions/*</code>.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/cloudbuildv2_connection#user_token_secret_version Cloudbuildv2Connection#user_token_secret_version}
     * Note: The above comment contained a comment block ending sequence (* followed by /). We have introduced a space between to prevent syntax errors. Please ignore the space.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getUserTokenSecretVersion();

    /**
     * @return a {@link Builder} of {@link Cloudbuildv2ConnectionGitlabConfigReadAuthorizerCredential}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link Cloudbuildv2ConnectionGitlabConfigReadAuthorizerCredential}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<Cloudbuildv2ConnectionGitlabConfigReadAuthorizerCredential> {
        java.lang.String userTokenSecretVersion;

        /**
         * Sets the value of {@link Cloudbuildv2ConnectionGitlabConfigReadAuthorizerCredential#getUserTokenSecretVersion}
         * @param userTokenSecretVersion Required. A SecretManager resource containing the user token that authorizes the Cloud Build connection. Format: <code>projects/* /secrets/* /versions/*</code>. This parameter is required.
         *                               Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/cloudbuildv2_connection#user_token_secret_version Cloudbuildv2Connection#user_token_secret_version}
         *                               
         *                               Note: The above comment contained a comment block ending sequence (* followed by /). We have introduced a space between to prevent syntax errors. Please ignore the space.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder userTokenSecretVersion(java.lang.String userTokenSecretVersion) {
            this.userTokenSecretVersion = userTokenSecretVersion;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link Cloudbuildv2ConnectionGitlabConfigReadAuthorizerCredential}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public Cloudbuildv2ConnectionGitlabConfigReadAuthorizerCredential build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link Cloudbuildv2ConnectionGitlabConfigReadAuthorizerCredential}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements Cloudbuildv2ConnectionGitlabConfigReadAuthorizerCredential {
        private final java.lang.String userTokenSecretVersion;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.userTokenSecretVersion = software.amazon.jsii.Kernel.get(this, "userTokenSecretVersion", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.userTokenSecretVersion = java.util.Objects.requireNonNull(builder.userTokenSecretVersion, "userTokenSecretVersion is required");
        }

        @Override
        public final java.lang.String getUserTokenSecretVersion() {
            return this.userTokenSecretVersion;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("userTokenSecretVersion", om.valueToTree(this.getUserTokenSecretVersion()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-google.cloudbuildv2Connection.Cloudbuildv2ConnectionGitlabConfigReadAuthorizerCredential"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            Cloudbuildv2ConnectionGitlabConfigReadAuthorizerCredential.Jsii$Proxy that = (Cloudbuildv2ConnectionGitlabConfigReadAuthorizerCredential.Jsii$Proxy) o;

            return this.userTokenSecretVersion.equals(that.userTokenSecretVersion);
        }

        @Override
        public final int hashCode() {
            int result = this.userTokenSecretVersion.hashCode();
            return result;
        }
    }
}

==> cdktf-provider-google-13.13.0-sources.jar: com/hashicorp/cdktf/providers/google/cloudbuildv2_connection/Cloudbuildv2ConnectionGitlabConfigReadAuthorizerCredential.java <==
package com.hashicorp.cdktf.providers.google.cloudbuildv2_connection;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.96.0 (build 921e240)", date = "2024-04-09T03:36:13.155Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.cloudbuildv2Connection.Cloudbuildv2ConnectionGitlabConfigReadAuthorizerCredential")
@software.amazon.jsii.Jsii.Proxy(Cloudbuildv2ConnectionGitlabConfigReadAuthorizerCredential.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface Cloudbuildv2ConnectionGitlabConfigReadAuthorizerCredential extends software.amazon.jsii.JsiiSerializable {

    /**
     * Required. A SecretManager resource containing the user token that authorizes the Cloud Build connection. Format: 'projects/* /secrets/* /versions/*'.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/cloudbuildv2_connection#user_token_secret_version Cloudbuildv2Connection#user_token_secret_version}
     * Note: The above comment contained a comment block ending sequence (* followed by /). We have introduced a space between to prevent syntax errors. Please ignore the space.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getUserTokenSecretVersion();

    /**
     * @return a {@link Builder} of {@link Cloudbuildv2ConnectionGitlabConfigReadAuthorizerCredential}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link Cloudbuildv2ConnectionGitlabConfigReadAuthorizerCredential}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<Cloudbuildv2ConnectionGitlabConfigReadAuthorizerCredential> {
        java.lang.String userTokenSecretVersion;

        /**
         * Sets the value of {@link Cloudbuildv2ConnectionGitlabConfigReadAuthorizerCredential#getUserTokenSecretVersion}
         * @param userTokenSecretVersion Required. A SecretManager resource containing the user token that authorizes the Cloud Build connection. Format: 'projects/* /secrets/* /versions/*'. This parameter is required.
         *                               Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/cloudbuildv2_connection#user_token_secret_version Cloudbuildv2Connection#user_token_secret_version}
         *                               
         *                               Note: The above comment contained a comment block ending sequence (* followed by /). We have introduced a space between to prevent syntax errors. Please ignore the space.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder userTokenSecretVersion(java.lang.String userTokenSecretVersion) {
            this.userTokenSecretVersion = userTokenSecretVersion;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link Cloudbuildv2ConnectionGitlabConfigReadAuthorizerCredential}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public Cloudbuildv2ConnectionGitlabConfigReadAuthorizerCredential build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link Cloudbuildv2ConnectionGitlabConfigReadAuthorizerCredential}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements Cloudbuildv2ConnectionGitlabConfigReadAuthorizerCredential {
        private final java.lang.String userTokenSecretVersion;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.userTokenSecretVersion = software.amazon.jsii.Kernel.get(this, "userTokenSecretVersion", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.userTokenSecretVersion = java.util.Objects.requireNonNull(builder.userTokenSecretVersion, "userTokenSecretVersion is required");
        }

        @Override
        public final java.lang.String getUserTokenSecretVersion() {
            return this.userTokenSecretVersion;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("userTokenSecretVersion", om.valueToTree(this.getUserTokenSecretVersion()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-google.cloudbuildv2Connection.Cloudbuildv2ConnectionGitlabConfigReadAuthorizerCredential"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            Cloudbuildv2ConnectionGitlabConfigReadAuthorizerCredential.Jsii$Proxy that = (Cloudbuildv2ConnectionGitlabConfigReadAuthorizerCredential.Jsii$Proxy) o;

            return this.userTokenSecretVersion.equals(that.userTokenSecretVersion);
        }

        @Override
        public final int hashCode() {
            int result = this.userTokenSecretVersion.hashCode();
            return result;
        }
    }
}
